=====
Scriv
=====

|pypi-badge| |travis-badge| |codecov-badge| |doc-badge| |pyversions-badge|
|license-badge|

Scriv changelog management tool

Overview
--------

Scriv is a command-line tool for helping developers maintain useful changelogs.
It manages a directory of changelog entries. It aggregates them into a
CHANGELOG file.

Documentation
-------------

The full documentation is at https://scriv.readthedocs.org.

License
-------

The code in this repository is licensed under the Apache Software License 2.0 unless
otherwise noted.

Please see ``LICENSE.txt`` for details.

How To Contribute
-----------------

Contributions are very welcome.

Please read `How To Contribute <https://github.com/edx/edx-platform/blob/master/CONTRIBUTING.rst>`_ for details.

Even though they were written with ``edx-platform`` in mind, the guidelines
should be followed for Open edX code in general.

Reporting Security Issues
-------------------------

Please do not report security issues in public. Please email security@edx.org.

Getting Help
------------

Have a question about this repository, or about Open edX in general?  Please
refer to this `list of resources`_ if you need any assistance.

.. _list of resources: https://open.edx.org/getting-help


.. |pypi-badge| image:: https://img.shields.io/pypi/v/scriv.svg
    :target: https://pypi.python.org/pypi/scriv/
    :alt: PyPI

.. |travis-badge| image:: https://travis-ci.org/edx/scriv.svg?branch=master
    :target: https://travis-ci.org/edx/scriv
    :alt: Travis

.. |codecov-badge| image:: http://codecov.io/github/edx/scriv/coverage.svg?branch=master
    :target: http://codecov.io/github/edx/scriv?branch=master
    :alt: Codecov

.. |doc-badge| image:: https://readthedocs.org/projects/scriv/badge/?version=latest
    :target: http://scriv.readthedocs.io/en/latest/
    :alt: Documentation

.. |pyversions-badge| image:: https://img.shields.io/pypi/pyversions/scriv.svg
    :target: https://pypi.python.org/pypi/scriv/
    :alt: Supported Python versions

.. |license-badge| image:: https://img.shields.io/github/license/edx/scriv.svg
    :target: https://github.com/edx/scriv/blob/master/LICENSE.txt
    :alt: License
